@@ -39,28 +39,9 @@ CLIENT_INTERMEDIATE_KEY = "client_intermediate.key"
 CLIENT_CERT = os.path.join(CERTS_PATH, CLIENT_INTERMEDIATE_PEM)
 PASSWORD_KEYFILE = os.path.join(CERTS_PATH, "server_password.key")
 PASSWORD_CLIENT_KEYFILE = os.path.join(CERTS_PATH, "client_password.key")
-NO_SAN_CERTS = {
-    "certfile": os.path.join(CERTS_PATH, "server.no_san.crt"),
-    "keyfile": DEFAULT_CERTS["keyfile"],
-}
-IP_SAN_CERTS = {
-    "certfile": os.path.join(CERTS_PATH, "server.ip_san.crt"),
-    "keyfile": DEFAULT_CERTS["keyfile"],
-}
-IPV6_ADDR_CERTS = {
-    "certfile": os.path.join(CERTS_PATH, "server.ipv6addr.crt"),
-    "keyfile": os.path.join(CERTS_PATH, "server.ipv6addr.key"),
-}
-IPV6_SAN_CERTS = {
-    "certfile": os.path.join(CERTS_PATH, "server.ipv6_san.crt"),
-    "keyfile": DEFAULT_CERTS["keyfile"],
-}
 DEFAULT_CA = os.path.join(CERTS_PATH, "cacert.pem")
 DEFAULT_CA_KEY = os.path.join(CERTS_PATH, "cacert.key")
 DEFAULT_CA_BAD = os.path.join(CERTS_PATH, "client_bad.pem")
-NO_SAN_CA = os.path.join(CERTS_PATH, "cacert.no_san.pem")
-IPV6_ADDR_CA = os.path.join(CERTS_PATH, "server.ipv6addr.crt")
-IPV6_SAN_CA = os.path.join(CERTS_PATH, "server.ipv6_san.crt")
 COMBINED_CERT_AND_KEY = os.path.join(CERTS_PATH, "server.combined.pem")
 
 
