@@ -4,7 +4,12 @@ import socket
 import pytest
 
 from dummyserver.testcase import HTTPDummyProxyTestCase, IPv6HTTPDummyProxyTestCase
-from dummyserver.server import DEFAULT_CA, DEFAULT_CA_BAD, get_unreachable_address
+from dummyserver.server import (
+    DEFAULT_CA,
+    DEFAULT_CA_BAD,
+    HAS_IPV6,
+    get_unreachable_address,
+)
 from .. import TARPIT_HOST, requires_network
 
 from urllib3._collections import HTTPHeaderDict
@@ -136,7 +141,6 @@ class TestHTTPProxyManager(HTTPDummyProxyTestCase):
                     "GET",
                     "%s/redirect" % self.http_url,
                     fields={"target": cross_host_location},
-                    timeout=LONG_TIMEOUT,
                     retries=0,
                 )
 
@@ -144,7 +148,6 @@ class TestHTTPProxyManager(HTTPDummyProxyTestCase):
                 "GET",
                 "%s/redirect" % self.http_url,
                 fields={"target": "%s/echo?a=b" % self.http_url_alt},
-                timeout=LONG_TIMEOUT,
                 retries=1,
             )
             assert r._pool.host != self.http_host_alt
@@ -157,7 +160,6 @@ class TestHTTPProxyManager(HTTPDummyProxyTestCase):
                     "GET",
                     "%s/redirect" % self.http_url,
                     fields={"target": cross_protocol_location},
-                    timeout=LONG_TIMEOUT,
                     retries=0,
                 )
 
@@ -165,7 +167,6 @@ class TestHTTPProxyManager(HTTPDummyProxyTestCase):
                 "GET",
                 "%s/redirect" % self.http_url,
                 fields={"target": "%s/echo?a=b" % self.https_url},
-                timeout=LONG_TIMEOUT,
                 retries=1,
             )
             assert r._pool.host == self.https_host
@@ -346,6 +347,7 @@ class TestHTTPProxyManager(HTTPDummyProxyTestCase):
             assert r.status == 200
 
 
+@pytest.mark.skipif(not HAS_IPV6, reason="Only runs on IPv6 systems")
 class TestIPv6HTTPProxyManager(IPv6HTTPDummyProxyTestCase):
     @classmethod
     def setup_class(cls):
